#!/bin/sh
# Mindtime Online Backup Pro Manager 5.5.8.0                      

#############################  DominoRecover.sh ###############################
# You can use this script file to recover your database files from command    #
# line. Just customize the "User Defined Section" below with the values for   #
# your recovery action.                                                       #
###############################################################################

#########################  Start: User Defined Section ########################


# ------------------------------ DATA_DIR ----------------------------------- #
# The Domino data directory which contains notes.ini,                         #
# the Domino databases, and templates.                                        #
# e.g. DATA_DIR=/local/notesdata                                              #
# --------------------------------------------------------------------------- #

DATA_DIR=/local/notesdata



# -------------------------------- LOTUS ------------------------------------ #
# The directory in which all Lotus products for UNIX are installed.           #
# e.g. LOTUS=/opt/ibm/lotus                                                   #
# --------------------------------------------------------------------------- #

LOTUS=/opt/ibm/lotus



# ------------------------------- INPUTFILE --------------------------------- #
# The path to an input file if you want to restore one database only.         #
# If you want to restore all databases, leave INPUTFILE blank.                #
# --------------------------------------------------------------------------- #

INPUTFILE=



# -------------------------------- RESTOREDB -------------------------------- #
# The path to a database file if you want to restore one database only.       #
# If you want to restore all databases, leave RESTOREDB blank.                #
# --------------------------------------------------------------------------- #

RESTOREDB=



# --------------------------------- RECDATE --------------------------------- #
# The month, day and year you want to recover the database to.                #
# The format of date must conform to the format used on your system.          #
# e.g RECDATE=11/15/2006                                                      #
# If you want to restore all databases leave RECDATE blank.                   #
# e.g RECDATE=                                                                #
# --------------------------------------------------------------------------- #

RECDATE=



# ---------------------------------- RECTIME -------------------------------- #
# The time in hour and minute you want to recover the database to.            #
# The format of time must conform to the format used on your system.          #
# e.g. RECTIME=14:30                                                          #
# If you want to restore all databases, leave RECTIME blank.                  #
# e.g. RECTIME=                                                               #
# --------------------------------------------------------------------------- #

RECTIME=



#############################  End: User Defined Section ######################

###############################################################################
#                 G L O B A L             P A R A M E T E R                   #
###############################################################################

# DEFINE argument LOTUS_RESTORE_ARG
# If both $INPUTFILE and $RESTOREDB are not empty string (null values),
# LOTUS_RESTORE_ARG will be set with "RESTORE" for LotusBM

LOTUS_RESTORE_ARG=

###############################################################################
#          P A R A M E T E R             V E R I F I C A T I O N              #
###############################################################################

length=${#DATA_DIR}
lastchar=${DATA_DIR:length-1:1}

if [ $lastchar != "/" ]; then
    DATA_DIR=${DATA_DIR}/
fi

FINDFILE=${DATA_DIR}notes.ini

if [ ! -f $FINDFILE ]; then
    echo "$FINDFILE does not exists"
    exit 1
fi

length=${#LOTUS}
lastchar=${LOTUS:length-1:1}

if [ $lastchar != "/" ]; then
    LOTUS=${LOTUS}/
fi

FINDFILE=${LOTUS}notes/latest/linux/libnotes.so

if [ ! -f $FINDFILE ]; then
    echo "Invalid canonical Lotus directory."
    exit 1
fi

if [ "${INPUTFILE}" != "" ]; then
    if [ ! -f $INPUTFILE ]; then
        echo "Invalid path to input database file"
        exit 1
    fi
fi

if [ "${RESTOREDB}" != "" ]; then
    if [ ! -f $RESTOREDB ]; then
        echo "Invalid path to restored database file"
        exit 1
    fi
fi

if [ "${INPUTFILE}" != "" ] || [ "${RESTOREDB}" != "" ]; then
    if [ "${INPUTFILE}" = "" ] || [ "${RESTOREDB}" = "" ]; then
        echo "Please enter both INPUTFILE and RESTOREDB if you want to restore one database."
        echo "If you want to restore all databases, leave them empty."
        exit 1
    fi
fi

if [ "${INPUTFILE}" != "" ] && [ "${RESTOREDB}" != "" ]; then
    LOTUS_RESTORE_ARG=RESTORE
    if [ "${INPUTFILE}" = "${RESTOREDB}" ]; then
        echo "INPUTFILE and RESTOREDB must be different."
        exit 1
    fi
fi

if [ "${INPUTFILE}" == "" ] && [ "${RECDATE}${RECTIME}" != "" ]; then
    echo "Please leave RECDATE and RECTIME blank if you want to recover all databases."
    exit 1
fi

if [ "${INPUTFILE}${RESTOREDB}" != "" ] && [ "${RECDATE}" == "" ] && [ "${RECTIME}" == "" ]; then
    echo "Please enter RECDATE and RECTIME if you want to recover one database only."
    exit 1
fi

if [ "${INPUTFILE}${RESTOREDB}" != "" ] && [ "${RECDATE}" == "" ]; then
    echo "Please enter RECDATE if you want to recover one database only."
    exit 1
fi

if [ "${INPUTFILE}${RESTOREDB}" != "" ] && [ "${RECTIME}" == "" ]; then
    echo "Please enter RECTIME if you want to recover one database only."
    exit 1
fi


###############################################################################
#      R E T R I E V E            A P P _ H O M E           P A T H           #
###############################################################################

EXE_DIR=`pwd`
SCRIPT_HOME=`dirname "$0"`
cd "$SCRIPT_HOME"
APP_BIN=`pwd`
APP_HOME=`dirname "$APP_BIN"`

###############################################################################
#           D O M I N O          P A T H         P R O P E R T I E S          #
###############################################################################

LOTUS=$LOTUS
NOTES_DATA_DIR=${DATA_DIR}
Notes_ExecDirectory=${LOTUS}notes/latest/linux/
PATH=${PATH}:${LOTUS}:${DATA_DIR}:${Notes_ExecDirectory}res/C
LD_LIBRARY_PATH=$APP_HOME/bin:$Notes_ExecDirectory:$LD_LIBRARY_PATH
export LOTUS NOTES_DATA_DIR Notes_ExecDirectory PATH LD_LIBRARY_PATH

###############################################################################
#               L O T U S B M                 E X E C U T I O N               #
###############################################################################

cd "$APP_HOME/bin"
./LotusBM $LOTUS_RESTORE_ARG $INPUTFILE $RESTOREDB $RECDATE $RECTIME

###############################################################################
#                   R E S E T          A N D          E X I T                 #
###############################################################################

cd "${EXE_DIR}"
exit 0
