#!/bin/sh

# This script is to config the OBM Run-Time Environment

test "`id -u`" = "0" || echo "Required root priviledge to install." || exit 1

# -------------------- Print Logging Message Header ----------------------------
echo "Log Time: `date`"

OS_IS_LINUX=0

case "`uname`" in
  Linux*)   
    echo "Start configuration on Generic Linux Platform (`uname`)"
    OS_IS_LINUX=1
    ;;
  Solaris*) echo "Start configuration on Solaris 2.X Platform (`uname`)";;
  SunOS*)   echo "Start configuration on Solaris 5.X Platform (`uname`)";;
  *BSD*)    echo "Start configuration on BSD distribution Platform (`uname`)";;
  **)       echo "This OS `uname` is not supported by this script! Exit `basename $0` now!"
      exit 0 ;;
esac

echo ""

# ------------------------- Retrieve APP_HOME ----------------------------------
cd `dirname "$0"`
APP_BIN=`pwd`
APP_HOME=`dirname "$APP_BIN"`
UTIL_HOME=${APP_HOME}/util
AUA_HOME=${APP_HOME}/aua
AUA_BIN=${AUA_HOME}/bin

echo "Installation Path: ${APP_HOME}"

# ----------------------- Configure Application --------------------------------
BUNDLED_JAVA_HOME=jvm

if [ "$OS_IS_LINUX" = "1" ]; then
  case "`uname -m`" in
    i[3-6]86)
      if [ -d "${APP_HOME}/jre32" ]; then
        BUNDLED_JAVA_HOME=jre32
      fi
      ;;
    x86_64 | amd64)
      if [ -d "${APP_HOME}/jre64" ]; then
        BUNDLED_JAVA_HOME=jre64
      fi
      ;;
    *)
      BUNDLED_JAVA_HOME=$JAVA_HOME
      ;;
  esac
fi

cd "${APP_HOME}"

if [ ! -x "${BUNDLED_JAVA_HOME}" ];
then 
   echo "$APP_HOME/jvm does not exist!"                      
   if [ !  -n "$JAVA_HOME" ]; then
     echo "Please set JAVA_HOME!"
     exit 0
   else
     ln -sf "$JAVA_HOME" "$APP_HOME/jvm"
     echo "Created JAVA_HOME symbolic link at $APP_HOME/jvm"
   fi
else
   ln -sf "${BUNDLED_JAVA_HOME}" "$APP_HOME/jvm"
   if `$APP_HOME/jvm/bin/java -version` ;
   then
     echo "JVM is verified for installation!"
   else
     echo "$APP_HOME/jvm/bin/java is not valid to execute on this platform!"
     echo "Please resolve before installation!"
     exit 0
   fi
fi

if [ ! -x "$APP_HOME/aua/jvm" ];
then
  ln -sf "$APP_HOME/jvm" "$APP_HOME/aua/jvm"
  echo "Created JAVA_HOME symbolic link at $APP_HOME/aua/jvm"
fi

if [ ! -x "$APP_HOME/jvm/bin/bJW" ]; then
  echo "Create Backup Manager JVM, Path: $APP_HOME/jvm/bin/bJW"
  ln -sf "$APP_HOME/jvm/bin/java" "$APP_HOME/jvm/bin/bJW"
  chmod 755 "$APP_HOME/jvm/bin/bJW"
fi

if [ ! -x "$APP_HOME/jvm/bin/bschJW" ]; then
  echo "Create Scheduler Service JVM, Path: $APP_HOME/jvm/bin/bschJW"
  ln -sf "$APP_HOME/jvm/bin/java" "$APP_HOME/jvm/bin/bschJW"
  chmod 755 "$APP_HOME/jvm/bin/bschJW"
fi

if [ ! -x "$APP_HOME/aua/jvm/bin/auaJW" ]; then
  echo "Create AutoUpdate Service JVM, Path: $APP_HOME/jvm/bin/auaJW"
  ln -sf "$APP_HOME/aua/jvm/bin/java" "$APP_HOME/aua/jvm/bin/auaJW"
  chmod 755 "$APP_HOME/aua/jvm/bin/auaJW"
fi

if [ ! -x "$APP_HOME/aua/jvm/lib/tools.jar" ]; then
  cp "$APP_HOME/aua/lib/tools.jar" "$APP_HOME/aua/jvm/lib/tools.jar"
fi

# Set File Permission
echo "Setup File Permissions"
touch "$APP_HOME/home.txt"
chmod 777 "$APP_HOME/home.txt"
chmod 777 "$APP_BIN/notesenv"
chmod 755 "$APP_BIN/LotusBM"
chmod 755 $APP_BIN/*.sh

# Disabled writing to config.ini since 5.2.2.6
#chmod 777 "$APP_HOME/config.ini"

echo "Configure AutoUpdate Service Property file: ${APP_HOME}/aua/builds/local-machine.properties"
cd "$APP_HOME/aua/bin"
./auas-config.sh > /dev/null

exit 0
