#!/bin/sh

# Required root priviledge to write system service script

test "`id -u`" = "0" || echo "Required root priviledge to install." || exit 1

# -------------------- Print Logging Message Header ----------------------------
echo "Log Time: `date`"

case "`uname`" in
  Linux*)   echo "Start installation on Generic Linux Platform (`uname`)";;
  Solaris*) echo "Start installation on Solaris 2.X Platform (`uname`)";;
  SunOS*)   echo "Start installation on Solaris 5.X Platform (`uname`)";;
  *BSD*)    echo "Start installation on BSD distribution Platform (`uname`)";;
  **)       echo "This OS `uname` is not supported by this script! Exit `basename $0` now!"
            exit 0 ;;
esac

echo ""

# ------------------------- Retrieve APP_HOME ----------------------------------
cd `dirname "$0"`
APP_BIN=`pwd`
APP_HOME=`dirname "$APP_BIN"`
UTIL_HOME=${APP_HOME}/util
AUA_HOME=${APP_HOME}/aua
AUA_BIN=${AUA_HOME}/bin

echo "Installation Path: ${APP_HOME}"

# ----------------------- Configure Application --------------------------------
cd "$APP_BIN"
echo "Configure Application Path: ${APP_HOME}"
./config.sh > config.log

# ------------------------- Install Scheduler ----------------------------------
echo "Installing Scheduler Service"
SCH_SCRIPT_PATH=${APP_BIN}
SCH_SCRIPT_NAME=obmscheduler

cd "${APP_BIN}"

# Create the service script
case "`uname`" in
  Linux*)   SCH_SCRIPT_SRC=scheduler ;;
  Solaris*) SCH_SCRIPT_SRC=scheduler ;;
  SunOS*)   SCH_SCRIPT_SRC=scheduler ;;
  *BSD*)    SCH_SCRIPT_SRC=scheduler-bsd ;;
  **)       echo "This OS `uname` is not supported by this script! Exit `basename $0` now!"
            exit 0 ;;
esac

sed "s|@sed.script.name@|${SCH_SCRIPT_NAME}|g" <./${SCH_SCRIPT_SRC} | sed "s|@sed.product.home@|${APP_HOME}|g" > ./${SCH_SCRIPT_NAME}

echo "Scheduler Service Script created at ${APP_BIN}/${SCH_SCRIPT_NAME}"

"${UTIL_HOME}/bin/install-service.sh" "${SCH_SCRIPT_PATH}/${SCH_SCRIPT_NAME}"

# ------------------------- Install AutoUpdate ---------------------------------
echo "Installing AutoUpdate Service"
AUA_SCRIPT_PATH=$AUA_BIN
AUA_SCRIPT_NAME=obmaua

cd "${AUA_BIN}"

case "`uname`" in
  Linux*)   AUA_SCRIPT_SRC=autoupdate ;;
  Solaris*) AUA_SCRIPT_SRC=autoupdate ;;
  SunOS*)   AUA_SCRIPT_SRC=autoupdate ;;
  *BSD*)    AUA_SCRIPT_SRC=autoupdate-bsd ;;
  **)       echo "This OS `uname` is not supported by this script! Exit `basename $0` now!"
            exit 0 ;;
esac

sed "s|@sed.script.name@|${AUA_SCRIPT_NAME}|g" <./${AUA_SCRIPT_SRC} | sed "s|@sed.autoupdate.home@|${AUA_HOME}|g" > ./${AUA_SCRIPT_NAME}
echo "AutoUpdate Service Script created at ${AUA_BIN}/${AUA_SCRIPT_NAME}"

"${UTIL_HOME}/bin/install-service.sh" "${AUA_SCRIPT_PATH}/${AUA_SCRIPT_NAME}"

# -------------------------- Startup Services ----------------------------------
echo "Run Scheduler Serivce"
sh "${APP_BIN}/Scheduler.sh" &
echo "Started Scheduler Serivce"

echo "Run AutoUpdate Serivce"
sh "${AUA_BIN}/startup.sh" &
echo "Started AutoUpdate Serivce"

exit 0
